@@ -44,7 +44,7 @@ class BaseFinancial:
             default = config.get("SERVER").get("GP")[0][1:]
             self.bestip = config.get("BESTIP").get("GP", default)
         except ValueError as ex:
-            logger.exception(ex)
+            logger.error(ex)
             self.bestip = ("106.14.95.149", 7727)
 
     def fetch_and_parse(self, report_hook=None, downdir=None, chunk_size=51200, *args, **kwargs):
