@@ -38,6 +38,11 @@ class Customize:
         """
 
         block_data = self.search()
+
+        if block_data.empty:
+            logger.error("自定义板块数据是空的")
+            return
+
         block_file = Path(self.vipdoc) / "blocknew.cfg"
         block_temp = block_data[block_data.blockname == name]
         block_type = ""
@@ -109,7 +114,7 @@ class Customize:
 
         # 对于名称空的情况, 直接创建写入
         if block_temp.empty:
-            logger.debug("block_temp is empty {}", block_temp.empty)
+            logger.debug(f"block_temp is empty {block_temp.empty}")
             return _blocknew(self.tdxdir, name=name, symbol=list(set(symbol)))
 
         # 覆盖情况
@@ -119,22 +124,24 @@ class Customize:
         # 取 blk 文件名, block_type 不为空
         if block_temp.block_type.to_list():
             block_type = list(set(block_temp.block_type.to_list()))[0]
-            logger.debug("发现板块文件: {}", block_type)
+            logger.debug(f"发现板块文件: {block_type}")
         else:
             # block_type 为空的话
             block_type = datetime.now().strftime("%Y%m%d%H%M%S")
-            logger.debug("板块文件找不到: {}", block_type)
+            logger.debug(f"板块文件找不到: {block_type}")
 
         # 去重股票代码
         block_code = list(set(block_code))
-        logger.debug("证券代码: {}", block_code)
+        logger.debug(f"证券代码: {block_code}")
 
         # 股票代码逗号隔开拼字符串
         block_code = "\n".join([f"{get_stock_market(s)}{s}" for s in block_code])
 
         # 写入 blk 文件
-        logger.debug("写入文件 : {}", Path(block_path, f"{block_type}.blk"))
-        return Path(block_path, f"{block_type}.blk").write_text(block_code, encoding="gb2312")
+        block_file = Path(block_path, f"{block_type}.blk")
+        logger.debug(f"写入文件 : {block_file}")
+
+        return block_file.write_text(block_code, encoding="gb2312")
 
 
 def _blocknew(tdxdir: str = None, name: str = None, symbol: list = None, blk_file: str = None, **kwargs):  # noqa
@@ -159,8 +166,6 @@ def _blocknew(tdxdir: str = None, name: str = None, symbol: list = None, blk_fil
     # 按时间生成 blk 文件名
     blk_file = blk_file if blk_file else str(time_ns())
 
-    print(symbol)
-
     vipdoc = Path(tdxdir, "T0002", "blocknew")
     symbol = list(set(symbol))
 
